#include "infowindow.h"
#include <QMaemo5ValueButton>
#include <QMaemo5ListPickSelector>
#include <QStandardItemModel>

int i = 0;
int h = 180, w = 760;
InfoWindow::InfoWindow(QWidget *parent) :
    QMainWindow(parent)
{
    setAttribute(Qt::WA_Maemo5StackedWindow);

    sw = new SettingsWindow(this);
    sw->hide();
    niw = new NewIngredientWindow(this);
    niw->hide();
    nw = new NewExerciseWindow(this);
    nw->hide();
    npw = new NewProgramWindow(this);
    npw->hide();
    ew = new ExerciseWindow(this);
    ew->hide();
    hw = new HistoryWindow(this);
    hw->hide();
    xml = new XML();



    QWidget *widget = new QWidget();
    setCentralWidget(widget);

    QVBoxLayout *vLayout = new QVBoxLayout;
    QHBoxLayout *hLabelLayout = new QHBoxLayout;
    gLayout = new QGridLayout();

    lblName = new QLabel("name");
    lblMuscle = new QLabel("muscle");
    lblSet = new QLabel("set");
    lblReps = new QLabel("reps");
    lblRest = new QLabel("rest");
    lblLast = new QLabel("last time");
    lblInfo = new QLabel("info on how to do");
    txtInfo = new QTextEdit();
    txtInfo->setReadOnly(true);

    lblInfo->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding);
    vLayout->addWidget(lblName);
    vLayout->addWidget(lblMuscle);

    hLabelLayout->addWidget(lblSet);
    hLabelLayout->addWidget(lblReps);
    hLabelLayout->addWidget(lblRest);
    vLayout->addLayout(hLabelLayout);

    vLayout->addWidget(lblLast);

    gLayout->addWidget(txtInfo);
    vLayout->addLayout(gLayout);

    gButtonLayout = new QGridLayout;
    btnBack = new QPushButton("<---");
    btnForward = new QPushButton("--->");
    btnStart = new QPushButton("Start");
    gButtonLayout->addWidget(btnBack,0,0);
    gButtonLayout->addWidget(btnForward,0,2);
    gButtonLayout->addWidget(btnStart,0,1);
    vLayout->addLayout(gButtonLayout);


    //vLayout->addWidget(btnStart);

    widget->setLayout(vLayout);
    createActions();
    createMenu();

    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
}

void InfoWindow::orientationChanged()
{
    QRect screenGeometry = QApplication::desktop()->screenGeometry();

    if (screenGeometry.width() > screenGeometry.height())
    {
        w = 760;
        h = 180;
    }
    else
    {
        w = 440;
        h = 550;
    }
    QPixmap bild(w,h);

    if(i == 1)
    {
        bild.load("/home/user/MyDocs/" + exerciseName + "1.png");
    }
    else if(i == 2)
    {
        bild.load("/home/user/MyDocs/" + exerciseName + "2.png");
    }
    bild = bild.scaled(w,h,Qt::KeepAspectRatio);
    lblInfo->setAlignment(Qt::AlignCenter);
    lblInfo->setPixmap(bild);
}

void InfoWindow::showHistory()
{
    hw->load();
    hw->show();
}

void InfoWindow::showNewIngredient()
{
    niw->load();
    niw->show();
}
void InfoWindow::showSettings()
{
    sw->load();
    sw->show();
}

void InfoWindow::showNewExercise()
{
    nw->load();
    nw->show();
}

void InfoWindow::showNewProgram()
{
    npw->show();
}

void InfoWindow::createMenu()
{
    QMenu *menu;
    menu = menuBar()->addMenu(tr("&Menu"));
    menu->addAction(historyAction);
    menu->addAction(settingsAction);
    menu->addAction(newExerciseAction);
    menu->addAction(newProgramAction);
    menu->addAction(newIngredientAction);
}

void InfoWindow::createActions()
{
    historyAction = new QAction("History",this);
    settingsAction = new QAction("Settings",this);
    newExerciseAction = new QAction("New Exercise",this);
    newProgramAction = new QAction("New program",this);
    newIngredientAction = new QAction("New Ingredient",this);

    connect(historyAction, SIGNAL(triggered()), this, SLOT(showHistory()));
    connect(settingsAction, SIGNAL(triggered()), this, SLOT(showSettings()));
    connect(newExerciseAction, SIGNAL(triggered()), this, SLOT(showNewExercise()));
    connect(newProgramAction, SIGNAL(triggered()), this, SLOT(showNewProgram()));
    connect(newIngredientAction, SIGNAL(triggered()), this, SLOT(showNewIngredient()));

    connect(btnStart,SIGNAL(clicked()),this,SLOT(startExercise()));
    connect(btnForward, SIGNAL(clicked()), this, SLOT(forward()));
    connect(btnBack, SIGNAL(clicked()), this, SLOT(back()));
}


void InfoWindow::loadExercise(QString name)
{
    QList <QString> list;
    QString weight[3], status[3];
    QString min, sec;
    QString reps[3], currentReps;

    exerciseName = name;
    qDebug() << name;
    list = xml->openEx(exerciseName);
    lblName->setText(list.takeFirst());
    list.takeFirst();
    lblMuscle->setText(list.takeFirst());
    info = list.takeFirst();

    weight[0] = list.takeFirst();
    weight[1] = list.takeFirst();
    weight[2] = list.takeFirst();

    status[0] = list.takeFirst();
    status[1] = list.takeFirst();
    status[2] = list.takeFirst();


    list = xml->loadSettings();
    if(list.isEmpty())
        return;

    list.removeLast();
    sec = list.takeLast(); min = list.takeLast();
    lblRest->setText(min + ":" + sec + " rest");

    currentReps = list.takeLast();
    reps[2] = list.takeLast();
    reps[1] = list.takeLast();
    reps[0] = list.takeLast();

    if(currentReps == "Low")
    {
        if(weight[0] != "0")
            lblLast->setText(weight[0] + "kg was " + status[0] + " last time.");
        else
            lblLast->setText("Exercise have never been done.");

        lblReps->setText(reps[0] + " Reps");
    }

    else if(currentReps == "Mid")
    {
        if(weight[1] != "0")
            lblLast->setText(weight[1] + "kg was " + status[1] + " last time.");
        else
            lblLast->setText("Exercise have never been done.");

        lblReps->setText(reps[1] + " Reps");
    }

    else
    {
        if(weight[2] != "0")
            lblLast->setText(weight[2] + "kg was " + status[2] + " last time.");
        else
            lblLast->setText("Exercise have never been done.");

        lblReps->setText(reps[2] + " Reps");
    }

    lblSet->setText(list.takeLast() + " Set");


    txtInfo->setText(info);


}

void InfoWindow::startExercise()
{
    QList <QString> list;
    list.append(exerciseName);

    ew->loadExercise(list);
    ew->show();
}

void InfoWindow::forward()
{
    if(i == 2)
    {
        i = 0;
        gLayout->removeWidget(lblInfo);
        lblInfo->hide();
        gLayout->addWidget(txtInfo);
        txtInfo->show();
        txtInfo->setText(info);
        return;
    }

    else if(i == 1)
    {
        //if(info[2] != "")
        //{
            QPixmap bild(w,h);
            bild.load("/home/user/MyDocs/" + exerciseName + "2.png");
            bild = bild.scaled(w,h,Qt::KeepAspectRatio);
            lblInfo->setAlignment(Qt::AlignCenter);
            lblInfo->setPixmap(bild);
            i++;
            //}
         return;
    }

    else if(i == 0)
    {
        //if(info[1] != "")
        //{
            gLayout->removeWidget(txtInfo);
            txtInfo->hide();
            gLayout->addWidget(lblInfo);
            lblInfo->show();
            QPixmap bild(w,h);
            bild.load("/home/user/MyDocs/" + exerciseName + "1.png");
            bild = bild.scaled(w,h,Qt::KeepAspectRatio);
            lblInfo->setAlignment(Qt::AlignCenter);
            lblInfo->setPixmap(bild);
            i++;
        //}
         return;
    }
}

void InfoWindow::back()
{
    if(i == 0)
    {
        //if(info[2] != "")
        //{
            gLayout->removeWidget(txtInfo);
            txtInfo->hide();
            gLayout->addWidget(lblInfo);
            lblInfo->show();
            QPixmap bild(w,h);
            bild.load("/home/user/MyDocs/" + exerciseName + "2.png");
            bild = bild.scaled(w,h,Qt::KeepAspectRatio);
            lblInfo->setAlignment(Qt::AlignCenter);
            lblInfo->setPixmap(bild);
            i=2;
        //}
         return;
    }
    else if(i == 1)
    {
        gLayout->removeWidget(lblInfo);
        lblInfo->hide();
        gLayout->addWidget(txtInfo);
        txtInfo->show();
        lblInfo->setAlignment(Qt::AlignLeft);
        lblInfo->setAlignment(Qt::AlignTop);
        lblInfo->setText(info);
        i--;
    }
    else if(i == 2)
    {
        //if(info[1] != "")
        //{
            QPixmap bild(w,h);
            bild.load("/home/user/MyDocs/" + exerciseName + "1.png");
            bild = bild.scaled(w,h,Qt::KeepAspectRatio);
            lblInfo->setAlignment(Qt::AlignCenter);
            lblInfo->setPixmap(bild);
            i--;
        //}
        return;

    }
}
